==> tika-2.7.0-src.zip: tika-2.7.0/tika-core/src/test/java/org/apache/tika/pipes/async/MockReporter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tika.pipes.async;

import org.apache.tika.config.Field;
import org.apache.tika.pipes.FetchEmitTuple;
import org.apache.tika.pipes.PipesReporter;
import org.apache.tika.pipes.PipesResult;

public class MockReporter extends PipesReporter {

    private String endpoint;

    @Override
    public void report(FetchEmitTuple t, PipesResult result, long elapsed) {

    }

    @Override
    public void error(Throwable t) {

    }

    @Override
    public void error(String msg) {

    }

    @Field
    public void setEndpoint(String endpoint) {
        this.endpoint = endpoint;
    }

    public String getEndpoint() {
        return endpoint;
    }

    @Override
    public String toString() {
        return "MockReporter{" + "endpoint='" + endpoint + '\'' + '}';
    }
}

==> tika-3.2.3-src.zip: tika-3.2.3/tika-core/src/test/java/org/apache/tika/pipes/async/MockReporter.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.tika.pipes.async;

import java.util.concurrent.ArrayBlockingQueue;

import org.apache.tika.config.Field;
import org.apache.tika.pipes.FetchEmitTuple;
import org.apache.tika.pipes.PipesReporter;
import org.apache.tika.pipes.PipesResult;

public class MockReporter extends PipesReporter {

    static ArrayBlockingQueue<PipesResult> RESULTS = new ArrayBlockingQueue<>(10000);

    private String endpoint;

    @Override
    public void report(FetchEmitTuple t, PipesResult result, long elapsed) {
        RESULTS.add(result);
    }

    @Override
    public void error(Throwable t) {

    }

    @Override
    public void error(String msg) {

    }

    @Field
    public void setEndpoint(String endpoint) {
        this.endpoint = endpoint;
    }

    public String getEndpoint() {
        return endpoint;
    }

    @Override
    public String toString() {
        return "MockReporter{" + "endpoint='" + endpoint + '\'' + '}';
    }
}
